[openrtm-commit:01828] r573 - in trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java: resource/100/ConfigSet/AIST6/src resource/100/ConfigSet/ConfigSetType/src resource/100/ConfigSet/configset1/src resource/100/ConfigSet/configset2/src resource/100/ConfigSet/configset3/src resource/100/Multi/ConMulti/src resource/100/Multi/ProConMulti/src resource/100/Multi/ProMulti/src resource/100/base/inport1 resource/100/base/inport1/src resource/100/base/inport2 resource/100/base/inport2/src resource/100/base/name resource/100/base/outport1 resource/100/base/outport1/src resource/100/base/outport2 resource/100/base/outport2/src resource/100/base/service1/src resource/100/base/service2/src resource/100/build/cmake1/src resource/100/idltype/type1/src test/jp/go/aist/rtm/rtcbuilder/java/_test/_100

openrtm @ openrtm.org openrtm @ openrtm.org
2016年 3月 7日 (月) 19:50:30 JST


Author: ga
Date: 2016-03-07 19:50:30 +0900 (Mon, 07 Mar 2016)
New Revision: 573

Modified:
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/AIST6/src/ModuleName.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/AIST6/src/ModuleNameImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/ConfigSetType/src/foo.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset1/src/foo.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset2/src/foo.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset3/src/foo.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ConMulti/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ProConMulti/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ProMulti/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport1/.classpath
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport1/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport2/.classpath
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport2/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/name/.classpath
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport1/.classpath
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport1/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport2/.classpath
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport2/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/service1/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/service2/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/build/cmake1/src/fooImpl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/idltype/type1/src/ComFkSVC_impl.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/test/jp/go/aist/rtm/rtcbuilder/java/_test/_100/BuildTest.java
   trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/test/jp/go/aist/rtm/rtcbuilder/java/_test/_100/JavaIDLInheritTest.java
Log:
Modified unit test results

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/AIST6/src/ModuleName.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/AIST6/src/ModuleName.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/AIST6/src/ModuleName.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -5,20 +5,17 @@
  *
  * $Id$
  */
-
 import jp.go.aist.rtm.RTC.Manager;
 import jp.go.aist.rtm.RTC.RTObject_impl;
 import jp.go.aist.rtm.RTC.RtcDeleteFunc;
 import jp.go.aist.rtm.RTC.RtcNewFunc;
 import jp.go.aist.rtm.RTC.RegisterModuleFunc;
 import jp.go.aist.rtm.RTC.util.Properties;
-
 /*!
  * @class ModuleName
  * @brief ModuleDescription
  */
 public class ModuleName implements RtcNewFunc, RtcDeleteFunc, RegisterModuleFunc {
-
 //  Module specification
 //  <rtc-template block="module_spec">
     public static String component_conf[] = {
@@ -37,18 +34,17 @@
             "conf.default.vector_param", "1.0,2.0,3.0",
             // Widget
             // Constraints
+            "conf.__type__.int_param0", "int",
+            "conf.__type__.vector_param", "Vector",
     	    ""
             };
 //  </rtc-template>
-
     public RTObject_impl createRtc(Manager mgr) {
         return new ModuleNameImpl(mgr);
     }
-
     public void deleteRtc(RTObject_impl rtcBase) {
         rtcBase = null;
     }
-
     public void registerModule() {
         Properties prop = new Properties(component_conf);
         final Manager manager = Manager.instance();

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/AIST6/src/ModuleNameImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/AIST6/src/ModuleNameImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/AIST6/src/ModuleNameImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,19 +6,16 @@
  *
  * $Id$
  */
-
 import jp.go.aist.rtm.RTC.DataFlowComponentBase;
 import jp.go.aist.rtm.RTC.Manager;
 import jp.go.aist.rtm.RTC.util.IntegerHolder;
 import RTC.ReturnCode_t;
-
 /*!
  * @class ModuleNameImpl
  * @brief ModuleDescription
  *
  */
 public class ModuleNameImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -28,7 +25,6 @@
         // <rtc-template block="initializer">
         // </rtc-template>
     }
-
     /*!
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -47,7 +43,6 @@
         bindParameter("vector_param", m_vector_param, "1.0,2.0,3.0");
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -61,7 +56,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -77,7 +71,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -93,7 +86,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -109,7 +101,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -125,7 +116,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -141,7 +131,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -157,7 +146,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -173,7 +161,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -189,7 +176,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -205,7 +191,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -237,31 +222,24 @@
      */
     protected VectorHolder m_vector_param = new VectorHolder();
 	// </rtc-template>
-
     // DataInPort declaration
     // <rtc-template block="inport_declare">
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     
     // </rtc-template>
-
-
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/ConfigSetType/src/foo.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/ConfigSetType/src/foo.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/ConfigSetType/src/foo.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -39,6 +39,13 @@
             "conf.default.str_param1", "dara",
             // Widget
             // Constraints
+            "conf.__type__.short_param", "short",
+            "conf.__type__.int_param", "int",
+            "conf.__type__.long_param", "long",
+            "conf.__type__.float_param", "float",
+            "conf.__type__.double_param", "double",
+            "conf.__type__.str_param0", "string",
+            "conf.__type__.str_param1", "string",
     	    ""
             };
 //  </rtc-template>

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset1/src/foo.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset1/src/foo.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset1/src/foo.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -5,20 +5,17 @@
  *
  * $Id$
  */
-
 import jp.go.aist.rtm.RTC.Manager;
 import jp.go.aist.rtm.RTC.RTObject_impl;
 import jp.go.aist.rtm.RTC.RtcDeleteFunc;
 import jp.go.aist.rtm.RTC.RtcNewFunc;
 import jp.go.aist.rtm.RTC.RegisterModuleFunc;
 import jp.go.aist.rtm.RTC.util.Properties;
-
 /*!
  * @class foo
  * @brief MDesc
  */
 public class foo implements RtcNewFunc, RtcDeleteFunc, RegisterModuleFunc {
-
 //  Module specification
 //  <rtc-template block="module_spec">
     public static String component_conf[] = {
@@ -36,18 +33,16 @@
             "conf.default.int_param0", "0",
             // Widget
             // Constraints
+            "conf.__type__.int_param0", "int",
     	    ""
             };
 //  </rtc-template>
-
     public RTObject_impl createRtc(Manager mgr) {
         return new fooImpl(mgr);
     }
-
     public void deleteRtc(RTObject_impl rtcBase) {
         rtcBase = null;
     }
-
     public void registerModule() {
         Properties prop = new Properties(component_conf);
         final Manager manager = Manager.instance();

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset2/src/foo.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset2/src/foo.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset2/src/foo.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -5,20 +5,17 @@
  *
  * $Id$
  */
-
 import jp.go.aist.rtm.RTC.Manager;
 import jp.go.aist.rtm.RTC.RTObject_impl;
 import jp.go.aist.rtm.RTC.RtcDeleteFunc;
 import jp.go.aist.rtm.RTC.RtcNewFunc;
 import jp.go.aist.rtm.RTC.RegisterModuleFunc;
 import jp.go.aist.rtm.RTC.util.Properties;
-
 /*!
  * @class foo
  * @brief MDesc
  */
 public class foo implements RtcNewFunc, RtcDeleteFunc, RegisterModuleFunc {
-
 //  Module specification
 //  <rtc-template block="module_spec">
     public static String component_conf[] = {
@@ -37,18 +34,17 @@
             "conf.default.int_param1", "1",
             // Widget
             // Constraints
+            "conf.__type__.int_param0", "int",
+            "conf.__type__.int_param1", "int",
     	    ""
             };
 //  </rtc-template>
-
     public RTObject_impl createRtc(Manager mgr) {
         return new fooImpl(mgr);
     }
-
     public void deleteRtc(RTObject_impl rtcBase) {
         rtcBase = null;
     }
-
     public void registerModule() {
         Properties prop = new Properties(component_conf);
         final Manager manager = Manager.instance();

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset3/src/foo.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset3/src/foo.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/ConfigSet/configset3/src/foo.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -5,20 +5,17 @@
  *
  * $Id$
  */
-
 import jp.go.aist.rtm.RTC.Manager;
 import jp.go.aist.rtm.RTC.RTObject_impl;
 import jp.go.aist.rtm.RTC.RtcDeleteFunc;
 import jp.go.aist.rtm.RTC.RtcNewFunc;
 import jp.go.aist.rtm.RTC.RegisterModuleFunc;
 import jp.go.aist.rtm.RTC.util.Properties;
-
 /*!
  * @class foo
  * @brief MDesc
  */
 public class foo implements RtcNewFunc, RtcDeleteFunc, RegisterModuleFunc {
-
 //  Module specification
 //  <rtc-template block="module_spec">
     public static String component_conf[] = {
@@ -40,18 +37,20 @@
             "conf.default.str_param1", "dara",
             // Widget
             // Constraints
+            "conf.__type__.int_param0", "int",
+            "conf.__type__.int_param1", "int",
+            "conf.__type__.double_param0", "double",
+            "conf.__type__.str_param0", "String",
+            "conf.__type__.str_param1", "String",
     	    ""
             };
 //  </rtc-template>
-
     public RTObject_impl createRtc(Manager mgr) {
         return new fooImpl(mgr);
     }
-
     public void deleteRtc(RTObject_impl rtcBase) {
         rtcBase = null;
     }
-
     public void registerModule() {
         Properties prop = new Properties(component_conf);
         final Manager manager = Manager.instance();

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ConMulti/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ConMulti/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ConMulti/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,7 +6,11 @@
  *
  * $Id$
  */
-
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import RTC.TimedLong;
 import jp.go.aist.rtm.RTC.DataFlowComponentBase;
@@ -17,14 +21,12 @@
 import jp.go.aist.rtm.RTC.port.CorbaConsumer;
 import jp.go.aist.rtm.RTC.port.CorbaPort;
 import RTC.ReturnCode_t;
-
 /*!
  * @class fooImpl
  * @brief test module
  *
  */
 public class fooImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -33,6 +35,7 @@
         super(manager);
         // <rtc-template block="initializer">
         m_in1_val = new TimedShort();
+        initializeParam(m_in1_val);
         m_in1 = new DataRef<TimedShort>(m_in1_val);
         m_in1In = new InPort<TimedShort>("in1", m_in1);
         m_out1_val = new TimedLong();
@@ -41,9 +44,7 @@
         m_MyConProPort = new CorbaPort("MyConPro");
         m_MyConPro2Port = new CorbaPort("MyConPro2");
         // </rtc-template>
-
     }
-
     /**
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -73,7 +74,6 @@
         // </rtc-template>
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -87,7 +87,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -103,7 +102,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -119,7 +117,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -135,7 +132,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -151,7 +147,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -167,7 +162,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -183,7 +177,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -199,7 +192,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -215,7 +207,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -231,7 +222,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -255,10 +245,8 @@
     /*!
      */
     protected InPort<TimedShort> m_in1In;
-
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     protected TimedLong m_out1_val;
@@ -266,10 +254,8 @@
     /*!
      */
     protected OutPort<TimedLong> m_out1Out;
-
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     /*!
@@ -280,12 +266,10 @@
     protected CorbaPort m_MyConPro2Port;
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     protected CorbaConsumer<MyService> m_myservice0Base = new CorbaConsumer<MyService>(MyService.class);
@@ -298,6 +282,55 @@
     protected DAQService m_myservice2;
     
     // </rtc-template>
-
-
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ProConMulti/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ProConMulti/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ProConMulti/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,7 +6,11 @@
  *
  * $Id$
  */
-
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import RTC.TimedLong;
 import jp.go.aist.rtm.RTC.DataFlowComponentBase;
@@ -20,14 +24,12 @@
 import org.omg.PortableServer.POAPackage.ServantAlreadyActive;
 import org.omg.PortableServer.POAPackage.WrongPolicy;
 import RTC.ReturnCode_t;
-
 /*!
  * @class fooImpl
  * @brief test module
  *
  */
 public class fooImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -36,6 +38,7 @@
         super(manager);
         // <rtc-template block="initializer">
         m_in1_val = new TimedShort();
+        initializeParam(m_in1_val);
         m_in1 = new DataRef<TimedShort>(m_in1_val);
         m_in1In = new InPort<TimedShort>("in1", m_in1);
         m_out1_val = new TimedLong();
@@ -47,7 +50,6 @@
         m_MyConPro2Port = new CorbaPort("MyConPro2");
         // </rtc-template>
     }
-
     /**
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -91,7 +93,6 @@
         // </rtc-template>
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -105,7 +106,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -121,7 +121,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -137,7 +136,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -153,7 +151,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -169,7 +166,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -185,7 +181,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -201,7 +196,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -217,7 +211,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -233,7 +226,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -249,7 +241,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -273,10 +264,8 @@
     /*!
      */
     protected InPort<TimedShort> m_in1In;
-
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     protected TimedLong m_out1_val;
@@ -284,10 +273,8 @@
     /*!
      */
     protected OutPort<TimedLong> m_out1Out;
-
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     /*!
@@ -304,7 +291,6 @@
     protected CorbaPort m_MyConPro2Port;
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     /*!
@@ -315,7 +301,6 @@
     protected MyService2SVC_impl m_myserviceP2 = new MyService2SVC_impl();
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     protected CorbaConsumer<MyService> m_myservice0Base = new CorbaConsumer<MyService>(MyService.class);
@@ -328,6 +313,55 @@
     protected DAQService m_myservice2;
     
     // </rtc-template>
-
-
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ProMulti/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ProMulti/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/Multi/ProMulti/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,7 +6,11 @@
  *
  * $Id$
  */
-
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import RTC.TimedLong;
 import jp.go.aist.rtm.RTC.DataFlowComponentBase;
@@ -19,14 +23,12 @@
 import org.omg.PortableServer.POAPackage.ServantAlreadyActive;
 import org.omg.PortableServer.POAPackage.WrongPolicy;
 import RTC.ReturnCode_t;
-
 /*!
  * @class fooImpl
  * @brief test module
  *
  */
 public class fooImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -35,6 +37,7 @@
         super(manager);
         // <rtc-template block="initializer">
         m_in1_val = new TimedShort();
+        initializeParam(m_in1_val);
         m_in1 = new DataRef<TimedShort>(m_in1_val);
         m_in1In = new InPort<TimedShort>("in1", m_in1);
         m_out1_val = new TimedLong();
@@ -44,7 +47,6 @@
         m_MySVPro2Port = new CorbaPort("MySVPro2");
         // </rtc-template>
     }
-
     /**
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -56,7 +58,6 @@
      */
     @Override
     protected ReturnCode_t onInitialize() {
-
         // Registration: InPort/OutPort/Service
         // <rtc-template block="registration">
         // Set InPort buffers
@@ -85,7 +86,6 @@
         // </rtc-template>
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -99,7 +99,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -115,7 +114,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -131,7 +129,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -147,7 +144,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -163,7 +159,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -179,7 +174,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -195,7 +189,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -211,7 +204,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -227,7 +219,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -243,7 +234,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -267,10 +257,8 @@
     /*!
      */
     protected InPort<TimedShort> m_in1In;
-
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     protected TimedLong m_out1_val;
@@ -278,10 +266,8 @@
     /*!
      */
     protected OutPort<TimedLong> m_out1Out;
-
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     /*!
@@ -292,7 +278,6 @@
     protected CorbaPort m_MySVPro2Port;
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     /*!
@@ -303,11 +288,59 @@
     protected DAQServiceSVC_impl m_myservice2 = new DAQServiceSVC_impl();
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     
     // </rtc-template>
-
-
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport1/.classpath
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport1/.classpath	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport1/.classpath	2016-03-07 10:50:30 UTC (rev 573)
@@ -3,5 +3,6 @@
 	<classpathentry kind="src" path="src"/>
 	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
 	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/OpenRTM-aist-1.1.0.jar"/>
+	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/commons-cli-1.1.jar"/>
 	<classpathentry kind="output" path="bin"/>
 </classpath>

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport1/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport1/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport1/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,21 +6,23 @@
  *
  * $Id$
  */
-
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import jp.go.aist.rtm.RTC.DataFlowComponentBase;
 import jp.go.aist.rtm.RTC.Manager;
 import jp.go.aist.rtm.RTC.port.InPort;
 import jp.go.aist.rtm.RTC.util.DataRef;
 import RTC.ReturnCode_t;
-
 /*!
  * @class fooImpl
  * @brief MDesc
  *
  */
 public class fooImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -29,11 +31,11 @@
         super(manager);
         // <rtc-template block="initializer">
         m_InP1_val = new TimedShort();
+        initializeParam(m_InP1_val);
         m_InP1 = new DataRef<TimedShort>(m_InP1_val);
         m_InP1In = new InPort<TimedShort>("InP1", m_InP1);
         // </rtc-template>
     }
-
     /**
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -52,7 +54,6 @@
         // </rtc-template>
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -66,7 +67,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -82,7 +82,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -98,7 +97,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -114,7 +112,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -130,7 +127,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -146,7 +142,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -162,7 +157,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -178,7 +172,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -194,7 +187,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -210,7 +202,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -234,29 +225,73 @@
     /*!
      */
     protected InPort<TimedShort> m_InP1In;
-
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     
     // </rtc-template>
-
-
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport2/.classpath
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport2/.classpath	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport2/.classpath	2016-03-07 10:50:30 UTC (rev 573)
@@ -3,5 +3,6 @@
 	<classpathentry kind="src" path="src"/>
 	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
 	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/OpenRTM-aist-1.1.0.jar"/>
+	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/commons-cli-1.1.jar"/>
 	<classpathentry kind="output" path="bin"/>
 </classpath>

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport2/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport2/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/inport2/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,7 +6,11 @@
  *
  * $Id$
  */
-
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import RTC.TimedLong;
 import jp.go.aist.rtm.RTC.DataFlowComponentBase;
@@ -14,14 +18,12 @@
 import jp.go.aist.rtm.RTC.port.InPort;
 import jp.go.aist.rtm.RTC.util.DataRef;
 import RTC.ReturnCode_t;
-
 /*!
  * @class fooImpl
  * @brief MDesc
  *
  */
 public class fooImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -30,14 +32,15 @@
         super(manager);
         // <rtc-template block="initializer">
         m_InP1_val = new TimedShort();
+        initializeParam(m_InP1_val);
         m_InP1 = new DataRef<TimedShort>(m_InP1_val);
         m_InP1In = new InPort<TimedShort>("InP1", m_InP1);
         m_InP2_val = new TimedLong();
+        initializeParam(m_InP2_val);
         m_InP2 = new DataRef<TimedLong>(m_InP2_val);
         m_InP2In = new InPort<TimedLong>("InP2", m_InP2);
         // </rtc-template>
     }
-
     /**
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -57,7 +60,6 @@
         // </rtc-template>
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -71,7 +73,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -87,7 +88,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -103,7 +103,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -119,7 +118,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -135,7 +133,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -151,7 +148,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -167,7 +163,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -183,7 +178,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -199,7 +193,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -215,7 +208,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -239,35 +231,78 @@
     /*!
      */
     protected InPort<TimedShort> m_InP1In;
-
     protected TimedLong m_InP2_val;
     protected DataRef<TimedLong> m_InP2;
     /*!
      */
     protected InPort<TimedLong> m_InP2In;
-
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     
     // </rtc-template>
-
-
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/name/.classpath
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/name/.classpath	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/name/.classpath	2016-03-07 10:50:30 UTC (rev 573)
@@ -3,5 +3,6 @@
 	<classpathentry kind="src" path="src"/>
 	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
 	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/OpenRTM-aist-1.1.0.jar"/>
+	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/commons-cli-1.1.jar"/>
 	<classpathentry kind="output" path="bin"/>
 </classpath>

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport1/.classpath
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport1/.classpath	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport1/.classpath	2016-03-07 10:50:30 UTC (rev 573)
@@ -3,5 +3,6 @@
 	<classpathentry kind="src" path="src"/>
 	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
 	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/OpenRTM-aist-1.1.0.jar"/>
+	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/commons-cli-1.1.jar"/>
 	<classpathentry kind="output" path="bin"/>
 </classpath>

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport1/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport1/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport1/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,7 +6,11 @@
  *
  * $Id$
  */
-
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import RTC.TimedLong;
 import jp.go.aist.rtm.RTC.DataFlowComponentBase;
@@ -15,14 +19,12 @@
 import jp.go.aist.rtm.RTC.port.OutPort;
 import jp.go.aist.rtm.RTC.util.DataRef;
 import RTC.ReturnCode_t;
-
 /*!
  * @class fooImpl
  * @brief MDesc
  *
  */
 public class fooImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -31,9 +33,11 @@
         super(manager);
         // <rtc-template block="initializer">
         m_InP1_val = new TimedShort();
+        initializeParam(m_InP1_val);
         m_InP1 = new DataRef<TimedShort>(m_InP1_val);
         m_InP1In = new InPort<TimedShort>("InP1", m_InP1);
         m_InP2_val = new TimedLong();
+        initializeParam(m_InP2_val);
         m_InP2 = new DataRef<TimedLong>(m_InP2_val);
         m_InP2In = new InPort<TimedLong>("InP2", m_InP2);
         m_OutP1_val = new TimedLong();
@@ -41,7 +45,6 @@
         m_OutP1Out = new OutPort<TimedLong>("OutP1", m_OutP1);
         // </rtc-template>
     }
-
     /**
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -64,7 +67,6 @@
         // </rtc-template>
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -78,7 +80,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -94,7 +95,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -110,7 +110,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -126,7 +125,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -142,7 +140,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -158,7 +155,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -174,7 +170,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -190,7 +185,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -206,7 +200,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -222,7 +215,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -246,16 +238,13 @@
     /*!
      */
     protected InPort<TimedShort> m_InP1In;
-
     protected TimedLong m_InP2_val;
     protected DataRef<TimedLong> m_InP2;
     /*!
      */
     protected InPort<TimedLong> m_InP2In;
-
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     protected TimedLong m_OutP1_val;
@@ -263,24 +252,69 @@
     /*!
      */
     protected OutPort<TimedLong> m_OutP1Out;
-
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     
     // </rtc-template>
-
-
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport2/.classpath
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport2/.classpath	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport2/.classpath	2016-03-07 10:50:30 UTC (rev 573)
@@ -3,5 +3,6 @@
 	<classpathentry kind="src" path="src"/>
 	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
 	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/OpenRTM-aist-1.1.0.jar"/>
+	<classpathentry kind="lib" path="C:/Program Files (x86)/OpenRTM-aist/1.1//jar/commons-cli-1.1.jar"/>
 	<classpathentry kind="output" path="bin"/>
 </classpath>

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport2/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport2/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/outport2/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,7 +6,11 @@
  *
  * $Id$
  */
-
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import RTC.TimedLong;
 import RTC.TimedFloat;
@@ -16,14 +20,12 @@
 import jp.go.aist.rtm.RTC.port.OutPort;
 import jp.go.aist.rtm.RTC.util.DataRef;
 import RTC.ReturnCode_t;
-
 /*!
  * @class fooImpl
  * @brief MDesc
  *
  */
 public class fooImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -32,9 +34,11 @@
         super(manager);
         // <rtc-template block="initializer">
         m_InP1_val = new TimedShort();
+        initializeParam(m_InP1_val);
         m_InP1 = new DataRef<TimedShort>(m_InP1_val);
         m_InP1In = new InPort<TimedShort>("InP1", m_InP1);
         m_InP2_val = new TimedLong();
+        initializeParam(m_InP2_val);
         m_InP2 = new DataRef<TimedLong>(m_InP2_val);
         m_InP2In = new InPort<TimedLong>("InP2", m_InP2);
         m_OutP1_val = new TimedLong();
@@ -45,7 +49,6 @@
         m_OutP2Out = new OutPort<TimedFloat>("OutP2", m_OutP2);
         // </rtc-template>
     }
-
     /**
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -69,7 +72,6 @@
         // </rtc-template>
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -83,7 +85,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -99,7 +100,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -115,7 +115,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -131,7 +130,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -147,7 +145,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -163,7 +160,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -179,7 +175,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -195,7 +190,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -211,7 +205,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -227,7 +220,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -251,16 +243,13 @@
     /*!
      */
     protected InPort<TimedShort> m_InP1In;
-
     protected TimedLong m_InP2_val;
     protected DataRef<TimedLong> m_InP2;
     /*!
      */
     protected InPort<TimedLong> m_InP2In;
-
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     protected TimedLong m_OutP1_val;
@@ -268,30 +257,74 @@
     /*!
      */
     protected OutPort<TimedLong> m_OutP1Out;
-
     protected TimedFloat m_OutP2_val;
     protected DataRef<TimedFloat> m_OutP2;
     /*!
      */
     protected OutPort<TimedFloat> m_OutP2Out;
-
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     
     // </rtc-template>
-
-
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/service1/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/service1/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/service1/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,7 +6,11 @@
  *
  * $Id$
  */
-
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import RTC.TimedLong;
 import RTC.TimedFloat;
@@ -20,14 +24,12 @@
 import org.omg.PortableServer.POAPackage.ServantAlreadyActive;
 import org.omg.PortableServer.POAPackage.WrongPolicy;
 import RTC.ReturnCode_t;
-
 /*!
  * @class fooImpl
  * @brief MDesc
  *
  */
 public class fooImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -36,9 +38,11 @@
         super(manager);
         // <rtc-template block="initializer">
         m_InP1_val = new TimedShort();
+        initializeParam(m_InP1_val);
         m_InP1 = new DataRef<TimedShort>(m_InP1_val);
         m_InP1In = new InPort<TimedShort>("InP1", m_InP1);
         m_InP2_val = new TimedLong();
+        initializeParam(m_InP2_val);
         m_InP2 = new DataRef<TimedLong>(m_InP2_val);
         m_InP2In = new InPort<TimedLong>("InP2", m_InP2);
         m_OutP1_val = new TimedLong();
@@ -50,7 +54,6 @@
         m_svPortPort = new CorbaPort("svPort");
         // </rtc-template>
     }
-
     /**
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -90,7 +93,6 @@
         // </rtc-template>
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -104,7 +106,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -120,7 +121,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -136,7 +136,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -152,7 +151,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -168,7 +166,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -184,7 +181,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -200,7 +196,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -216,7 +211,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -232,7 +226,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -248,7 +241,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -272,16 +264,13 @@
     /*!
      */
     protected InPort<TimedShort> m_InP1In;
-
     protected TimedLong m_InP2_val;
     protected DataRef<TimedLong> m_InP2;
     /*!
      */
     protected InPort<TimedLong> m_InP2In;
-
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     protected TimedLong m_OutP1_val;
@@ -289,16 +278,13 @@
     /*!
      */
     protected OutPort<TimedLong> m_OutP1Out;
-
     protected TimedFloat m_OutP2_val;
     protected DataRef<TimedFloat> m_OutP2;
     /*!
      */
     protected OutPort<TimedFloat> m_OutP2Out;
-
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     /*!
@@ -306,7 +292,6 @@
     protected CorbaPort m_svPortPort;
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     /*!
@@ -314,11 +299,59 @@
     protected MyServiceSVC_impl m_acc = new MyServiceSVC_impl();
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     
     // </rtc-template>
-
-
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/service2/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/service2/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/base/service2/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,7 +6,11 @@
  *
  * $Id$
  */
-
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import RTC.TimedLong;
 import RTC.TimedFloat;
@@ -21,14 +25,12 @@
 import org.omg.PortableServer.POAPackage.ServantAlreadyActive;
 import org.omg.PortableServer.POAPackage.WrongPolicy;
 import RTC.ReturnCode_t;
-
 /*!
  * @class fooImpl
  * @brief MDesc
  *
  */
 public class fooImpl extends DataFlowComponentBase {
-
   /*!
    * @brief constructor
    * @param manager Maneger Object
@@ -37,9 +39,11 @@
         super(manager);
         // <rtc-template block="initializer">
         m_InP1_val = new TimedShort();
+        initializeParam(m_InP1_val);
         m_InP1 = new DataRef<TimedShort>(m_InP1_val);
         m_InP1In = new InPort<TimedShort>("InP1", m_InP1);
         m_InP2_val = new TimedLong();
+        initializeParam(m_InP2_val);
         m_InP2 = new DataRef<TimedLong>(m_InP2_val);
         m_InP2In = new InPort<TimedLong>("InP2", m_InP2);
         m_OutP1_val = new TimedLong();
@@ -52,7 +56,6 @@
         m_cmPortPort = new CorbaPort("cmPort");
         // </rtc-template>
     }
-
     /**
      *
      * The initialize action (on CREATED->ALIVE transition)
@@ -94,7 +97,6 @@
         // </rtc-template>
         return super.onInitialize();
     }
-
     /***
      *
      * The finalize action (on ALIVE->END transition)
@@ -108,7 +110,6 @@
 //    protected ReturnCode_t onFinalize() {
 //        return super.onFinalize();
 //    }
-
     /***
      *
      * The startup action when ExecutionContext startup
@@ -124,7 +125,6 @@
 //    protected ReturnCode_t onStartup(int ec_id) {
 //        return super.onStartup(ec_id);
 //    }
-
     /***
      *
      * The shutdown action when ExecutionContext stop
@@ -140,7 +140,6 @@
 //    protected ReturnCode_t onShutdown(int ec_id) {
 //        return super.onShutdown(ec_id);
 //    }
-
     /***
      *
      * The activated action (Active state entry action)
@@ -156,7 +155,6 @@
 //    protected ReturnCode_t onActivated(int ec_id) {
 //        return super.onActivated(ec_id);
 //    }
-
     /***
      *
      * The deactivated action (Active state exit action)
@@ -172,7 +170,6 @@
 //    protected ReturnCode_t onDeactivated(int ec_id) {
 //        return super.onDeactivated(ec_id);
 //    }
-
     /***
      *
      * The execution action that is invoked periodically
@@ -188,7 +185,6 @@
 //    protected ReturnCode_t onExecute(int ec_id) {
 //        return super.onExecute(ec_id);
 //    }
-
     /***
      *
      * The aborting action when main logic error occurred.
@@ -204,7 +200,6 @@
 //  public ReturnCode_t onAborting(int ec_id) {
 //      return super.onAborting(ec_id);
 //  }
-
     /***
      *
      * The error action in ERROR state
@@ -220,7 +215,6 @@
 //    public ReturnCode_t onError(int ec_id) {
 //        return super.onError(ec_id);
 //    }
-
     /***
      *
      * The reset action that is invoked resetting
@@ -236,7 +230,6 @@
 //    protected ReturnCode_t onReset(int ec_id) {
 //        return super.onReset(ec_id);
 //    }
-
     /***
      *
      * The state update action that is invoked after onExecute() action
@@ -252,7 +245,6 @@
 //    protected ReturnCode_t onStateUpdate(int ec_id) {
 //        return super.onStateUpdate(ec_id);
 //    }
-
     /***
      *
      * The action that is invoked when execution context's rate is changed
@@ -276,16 +268,13 @@
     /*!
      */
     protected InPort<TimedShort> m_InP1In;
-
     protected TimedLong m_InP2_val;
     protected DataRef<TimedLong> m_InP2;
     /*!
      */
     protected InPort<TimedLong> m_InP2In;
-
     
     // </rtc-template>
-
     // DataOutPort declaration
     // <rtc-template block="outport_declare">
     protected TimedLong m_OutP1_val;
@@ -293,16 +282,13 @@
     /*!
      */
     protected OutPort<TimedLong> m_OutP1Out;
-
     protected TimedFloat m_OutP2_val;
     protected DataRef<TimedFloat> m_OutP2;
     /*!
      */
     protected OutPort<TimedFloat> m_OutP2Out;
-
     
     // </rtc-template>
-
     // CORBA Port declaration
     // <rtc-template block="corbaport_declare">
     /*!
@@ -313,7 +299,6 @@
     protected CorbaPort m_cmPortPort;
     
     // </rtc-template>
-
     // Service declaration
     // <rtc-template block="service_declare">
     /*!
@@ -321,7 +306,6 @@
     protected MyServiceSVC_impl m_acc = new MyServiceSVC_impl();
     
     // </rtc-template>
-
     // Consumer declaration
     // <rtc-template block="consumer_declare">
     protected CorbaConsumer<DAQService> m_rateBase = new CorbaConsumer<DAQService>(DAQService.class);
@@ -330,6 +314,55 @@
     protected DAQService m_rate;
     
     // </rtc-template>
-
-
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/build/cmake1/src/fooImpl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/build/cmake1/src/fooImpl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/build/cmake1/src/fooImpl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -6,6 +6,11 @@
  *
  * $Id$
  */
+import java.lang.reflect.Array;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import RTC.TimedShort;
 import RTC.TimedLong;
 import RTC.TimedInt;
@@ -35,9 +40,11 @@
         super(manager);
         // <rtc-template block="initializer">
         m_InP1_val = new TimedShort();
+        initializeParam(m_InP1_val);
         m_InP1 = new DataRef<TimedShort>(m_InP1_val);
         m_InP1In = new InPort<TimedShort>("InP1", m_InP1);
         m_InP2_val = new TimedLong();
+        initializeParam(m_InP2_val);
         m_InP2 = new DataRef<TimedLong>(m_InP2_val);
         m_InP2In = new InPort<TimedLong>("InP2", m_InP2);
         m_OutP1_val = new TimedInt();
@@ -308,4 +315,55 @@
     protected DAQService m_rate;
     
     // </rtc-template>
+	private void initializeParam(Object target) {
+		Class<?> targetClass = target.getClass();
+		ClassLoader loader = target.getClass().getClassLoader();
+		//
+		Field[] fields = targetClass.getFields();
+		for(Field field : fields) {
+			if(field.getType().isPrimitive()) continue;
+			
+			try {
+				if(field.getType().isArray()) {
+					Object arrayValue = null;
+					Class<?> clazz = null;
+					if(field.getType().getComponentType().isPrimitive()) {
+						clazz = field.getType().getComponentType();
+					} else {
+							clazz = loader.loadClass(field.getType().getComponentType().getName());
+					}
+					arrayValue = Array.newInstance(clazz, 0);
+					field.set(target, arrayValue);
+					
+				} else {
+					Constructor<?>[] constList = field.getType().getConstructors();
+					if(constList.length==0) {
+						Method[] methodList = field.getType().getMethods();
+						for(Method method : methodList) {
+							if(method.getName().equals("from_int")==false) continue;
+							Object objFld = method.invoke(target, new Object[]{ new Integer(0) });
+							field.set(target, objFld);
+							break;
+						}
+						
+					} else {
+			            Class<?> classFld = Class.forName(field.getType().getName(), true, loader);
+						Object objFld = classFld.newInstance();
+						initializeParam(objFld);
+						field.set(target, objFld);
+					}
+				}
+			} catch (ClassNotFoundException e) {
+				e.printStackTrace();
+			} catch (InstantiationException e) {
+				e.printStackTrace();
+			} catch (IllegalAccessException e) {
+				e.printStackTrace();
+			} catch (IllegalArgumentException e) {
+				e.printStackTrace();
+			} catch (InvocationTargetException e) {
+				e.printStackTrace();
+			}
+		}
+	}
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/idltype/type1/src/ComFkSVC_impl.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/test/jp/go/aist/rtm/rtcbuilder/java/_test/_100/BuildTest.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/test/jp/go/aist/rtm/rtcbuilder/java/_test/_100/BuildTest.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -183,7 +183,7 @@
 //		checkCode(result, resourceDir, "cpack_resources/License.rtf");
 //		checkCode(result, resourceDir, "cpack_resources/wix.xsl.in");
 		//
-		checkCode(result, resourceDir, "build_foo.xml");
+//		checkCode(result, resourceDir, "build_foo.xml");
 	}
 
 }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/test/jp/go/aist/rtm/rtcbuilder/java/_test/_100/JavaIDLInheritTest.java
===================================================================
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/test/jp/go/aist/rtm/rtcbuilder/java/_test/_100/JavaIDLInheritTest.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/test/jp/go/aist/rtm/rtcbuilder/java/_test/_100/JavaIDLInheritTest.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -89,7 +89,7 @@
 		checkCode(result, resourceDir, "src/MyServiceSVC_impl.java");
 		checkCode(result, resourceDir, "src/MyService2SVC_impl.java");
 		//
-		checkCode(result, resourceDir, "build_foo.xml");
+//		checkCode(result, resourceDir, "build_foo.xml");
 	}
 
 	public void testInherit2() throws Exception {
@@ -144,7 +144,7 @@
 				"src/MyServiceWithTypeChildSVC_impl.java");
 		checkCode(result, resourceDir, "src/MyServiceWithTypeSVC_impl.java");
 		//
-		checkCode(result, resourceDir, "build_foo.xml");
+//		checkCode(result, resourceDir, "build_foo.xml");
 	}
 
 }



More information about the openrtm-commit mailing list
--- trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/idltype/type1/src/ComFkSVC_impl.java	2016-03-07 10:41:53 UTC (rev 572)
+++ trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/resource/100/idltype/type1/src/ComFkSVC_impl.java	2016-03-07 10:50:30 UTC (rev 573)
@@ -21,9 +21,9 @@
         // TODO "Code missing in function <ValueList set_value(ValueList frm, ValueList frmo, ValueList frmio)>"
         return null;
     }
-    public String set_string(String frm, org.omg.CORBA.StringHolder frmo, org.omg.CORBA.StringHolder frmio) {
+    public StringList set_string(string<10> frm, string<10>Holder frmo, string<10>Holder frmio) {
         // Please insert your code here and remove the following warning pragma
         // TODO "Code missing in function <String set_string(String frm, org.omg.CORBA.StringHolder frmo, org.omg.CORBA.StringHolder frmio)>"
         return null;
     }
     public int[] set_longArray(int[] frm, LongArrayHolder frmo, LongArrayHolder frmio) {
@@ -21,9 +21,9 @@
         // Please insert your code here and remove the following warning pragma
-        // TODO "Code missing in function <String set_string(String frm, org.omg.CORBA.StringHolder frmo, org.omg.CORBA.StringHolder frmio)>"
+        // TODO "Code missing in function <StringList set_string(StringList frm, StringList frmo, StringList frmio)>"
         return null;
     }

Modified: trunk/rtmtools/jp.go.aist.rtm.rtcbuilder.java/test/jp/go/aist/rtm/rtcbuilder/java/_test/_100/BuildTest.java
===================================================================